"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
class DataImporter {
    constructor(db, log) {
        this.db = db;
        this.log = log;
        this.importData = (config) => __awaiter(this, void 0, void 0, function* () {
            const collectionsDirs = yield fs_extra_1.readdir(config.dataPath);
            const collections = yield this.db.listCollections().toArray();
            for (const collectionDir of collectionsDirs) {
                // Directory name pattern: {import order}-{collection name}
                // Objective: to ensure correct import order - i.e. 1-categories
                const collectionName = collectionDir.includes('-')
                    ? collectionDir.split('-')[1]
                    : collectionDir;
                const collectionPath = `${config.dataPath}/${collectionDir}`;
                const stats = yield fs_extra_1.lstat(collectionPath);
                if (!stats.isDirectory()) {
                    continue;
                }
                yield this.createCollectionIfShould(collections, collectionName);
                yield this.insertDocuments(collectionName, collectionPath, config);
            }
        });
        this.createCollectionIfShould = (collections, collectionName) => __awaiter(this, void 0, void 0, function* () {
            if (!collections.some(collection => collection.name === collectionName)) {
                this.log(`Creating collection ${collectionName}...`);
                yield this.db.createCollection(collectionName);
            }
        });
        this.insertDocuments = (collectionName, collectionPath, config) => __awaiter(this, void 0, void 0, function* () {
            const fileNames = (yield fs_extra_1.readdir(collectionPath)) || [];
            const documentFileNames = fileNames.filter(fileName => {
                const fileNameArray = fileName.split('.');
                if (!fileNameArray || fileNameArray.length <= 1) {
                    return false;
                }
                const fileExtension = fileNameArray.pop().toLowerCase();
                return config.supportedExtensions.some(extension => extension === fileExtension);
            });
            this.log(`Inserting documents into collection ${collectionName}...`);
            const documents = documentFileNames.reduce((arr, documentFileName) => {
                const document = require(`${collectionPath}/${documentFileName}`);
                return arr.concat(document);
            }, []);
            const documentsToInsert = config.convertId
                ? this.setProperDocumentId(documents)
                : documents;
            yield this.db.collection(collectionName).insertMany(documentsToInsert);
        });
        this.setProperDocumentId = (documents) => {
            return documents.map(document => {
                const documentToInsert = Object.assign({}, document, { _id: document.id });
                delete documentToInsert.id;
                return documentToInsert;
            });
        };
    }
}
exports.DataImporter = DataImporter;
//# sourceMappingURL=DataImporter.js.map