"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const CONNECTION_REFUSED_ERROR_CODE = 'ECONNREFUSED';
const sleep = (time) => new Promise(resolve => setTimeout(resolve, time));
exports.connectToDatabase = ({ host, port, name, protocol }, reconnectTimeout, log) => __awaiter(this, void 0, void 0, function* () {
    const uri = `${protocol}://${host}:${port}/${name}`;
    log(`Connecting to ${uri}...`);
    let db;
    do {
        try {
            db = yield mongodb_1.MongoClient.connect(uri, { ignoreUndefined: true });
            log('Connection with database established.');
        }
        catch (err) {
            if (!err.message.includes(CONNECTION_REFUSED_ERROR_CODE)) {
                throw err;
            }
            log(`${err.message} Retrying...`);
            yield sleep(reconnectTimeout);
        }
    } while (!db);
    return db;
});
//# sourceMappingURL=connectToDatabase.js.map